@@ -7,13 +7,18 @@ from jupyter_server.extension.handler import ExtensionHandlerMixin
 from jupyter_server.utils import ensure_async
 
 from jupyter_scheduler.environments import EnvironmentRetrievalError
-from jupyter_scheduler.exceptions import IdempotencyTokenError, InputUriError
+from jupyter_scheduler.exceptions import (
+    IdempotencyTokenError,
+    InputUriError,
+    SchedulerError,
+)
 from jupyter_scheduler.models import (
     DEFAULT_MAX_ITEMS,
     DEFAULT_SORT,
     CountJobsQuery,
     CreateJob,
     CreateJobDefinition,
+    CreateJobFromDefinition,
     ListJobDefinitionsQuery,
     ListJobsQuery,
     SortDirection,
@@ -100,10 +105,13 @@ class JobDefinitionHandler(ExtensionHandlerMixin, JobHandlersMixin, APIHandler):
         except InputUriError as e:
             self.log.exception(e)
             raise tornado.web.HTTPError(500, str(e)) from e
+        except SchedulerError as e:
+            self.log.exception(e)
+            raise tornado.web.HTTPError(500, str(e)) from e
         except Exception as e:
             self.log.exception(e)
             raise tornado.web.HTTPError(
-                500, "Unexpected error occurred during creation of Job."
+                500, "Unexpected error occurred during creation of job."
             ) from e
         else:
             self.finish(json.dumps(dict(job_definition_id=job_definition_id)))
@@ -159,10 +167,13 @@ class JobHandler(ExtensionHandlerMixin, JobHandlersMixin, APIHandler):
         except IdempotencyTokenError as e:
             self.log.exception(e)
             raise tornado.web.HTTPError(409, str(e)) from e
+        except SchedulerError as e:
+            self.log.exception(e)
+            raise tornado.web.HTTPError(500, str(e)) from e
         except Exception as e:
             self.log.exception(e)
             raise tornado.web.HTTPError(
-                500, "Unexpected error occurred during creation of Job."
+                500, "Unexpected error occurred during creation of job."
             ) from e
         else:
             self.finish(json.dumps(dict(job_id=job_id)))
@@ -196,6 +207,27 @@ class JobHandler(ExtensionHandlerMixin, JobHandlersMixin, APIHandler):
         self.finish()
 
 
+class JobFromDefinitionHandler(ExtensionHandlerMixin, JobHandlersMixin, APIHandler):
+    @tornado.web.authenticated
+    async def post(self, job_definition_id: str):
+        payload = self.get_json_body()
+        try:
+            model = CreateJobFromDefinition(**payload)
+            job_id = await ensure_async(
+                self.scheduler.create_job_from_definition(job_definition_id, model=model)
+            )
+        except SchedulerError as e:
+            self.log.exception(e)
+            raise tornado.web.HTTPError(500, str(e)) from e
+        except Exception as e:
+            self.log.exception(e)
+            raise tornado.web.HTTPError(
+                500, "Unexpected error occurred during creation of job."
+            ) from e
+        else:
+            self.finish(json.dumps(dict(job_id=job_id)))
+
+
 class BatchJobHandler(ExtensionHandlerMixin, JobHandlersMixin, APIHandler):
     @tornado.web.authenticated
     async def delete(self):
