@@ -5,8 +5,7 @@ from typing import Dict, List, Optional, Union
 from pydantic import BaseModel, root_validator
 
 Tags = List[str]
-ParameterValues = Union[int, str, float, bool]
-EnvironmentParameterValues = Union[int, str, float, bool]
+EnvironmentParameterValues = Union[int, float, bool, str]
 
 EMAIL_RE = ""
 SCHEDULE_RE = ""
@@ -80,9 +79,9 @@ class CreateJob(BaseModel):
     output_formats: Optional[List[str]] = None
     idempotency_token: Optional[str] = None
     job_definition_id: Optional[str] = None
-    parameters: Optional[Dict[str, ParameterValues]] = None
+    parameters: Optional[Dict[str, str]] = None
     tags: Optional[Tags] = None
-    name: Optional[str] = None
+    name: str
     output_filename_template: Optional[str] = OUTPUT_FILENAME_TEMPLATE
     compute_type: Optional[str] = None
 
@@ -130,9 +129,9 @@ class DescribeJob(BaseModel):
     output_formats: Optional[List[str]] = None
     idempotency_token: Optional[str] = None
     job_definition_id: Optional[str] = None
-    parameters: Optional[Dict[str, ParameterValues]] = None
+    parameters: Optional[Dict[str, str]] = None
     tags: Optional[Tags] = None
-    name: Optional[str] = None
+    name: str
     output_filename_template: Optional[str] = OUTPUT_FILENAME_TEMPLATE
     compute_type: Optional[str] = None
     job_id: str
@@ -202,9 +201,9 @@ class CreateJobDefinition(BaseModel):
     runtime_environment_name: str
     runtime_environment_parameters: Optional[Dict[str, EnvironmentParameterValues]]
     output_formats: Optional[List[str]] = None
-    parameters: Optional[Dict[str, ParameterValues]] = None
+    parameters: Optional[Dict[str, str]] = None
     tags: Optional[Tags] = None
-    name: Optional[str] = None
+    name: str
     output_filename_template: Optional[str] = OUTPUT_FILENAME_TEMPLATE
     compute_type: Optional[str] = None
     schedule: Optional[str] = None
@@ -223,9 +222,9 @@ class DescribeJobDefinition(BaseModel):
     runtime_environment_name: str
     runtime_environment_parameters: Optional[Dict[str, EnvironmentParameterValues]]
     output_formats: Optional[List[str]] = None
-    parameters: Optional[Dict[str, ParameterValues]] = None
+    parameters: Optional[Dict[str, str]] = None
     tags: Optional[Tags] = None
-    name: Optional[str] = None
+    name: str
     output_filename_template: Optional[str] = OUTPUT_FILENAME_TEMPLATE
     compute_type: Optional[str] = None
     schedule: Optional[str] = None
@@ -243,7 +242,7 @@ class UpdateJobDefinition(BaseModel):
     runtime_environment_name: Optional[str]
     runtime_environment_parameters: Optional[Dict[str, EnvironmentParameterValues]]
     output_formats: Optional[List[str]] = None
-    parameters: Optional[Dict[str, ParameterValues]] = None
+    parameters: Optional[Dict[str, str]] = None
     tags: Optional[Tags] = None
     name: Optional[str] = None
     url: Optional[str] = None
@@ -269,6 +268,10 @@ class ListJobDefinitionsResponse(BaseModel):
     next_token: Optional[str] = None
 
 
+class CreateJobFromDefinition(BaseModel):
+    parameters: Optional[Dict[str, str]] = None
+
+
 class JobFeature(str, Enum):
     job_name = "job_name"
     parameters = "parameters"
