@@ -1,4 +1,5 @@
 import os
+import shutil
 from multiprocessing import Process
 from typing import Dict, Optional, Type, Union
 
@@ -14,11 +15,16 @@ from traitlets import Unicode, default
 from traitlets.config import LoggingConfigurable
 
 from jupyter_scheduler.environments import EnvironmentManager
-from jupyter_scheduler.exceptions import IdempotencyTokenError, InputUriError
+from jupyter_scheduler.exceptions import (
+    IdempotencyTokenError,
+    InputUriError,
+    SchedulerError,
+)
 from jupyter_scheduler.models import (
     CountJobsQuery,
     CreateJob,
     CreateJobDefinition,
+    CreateJobFromDefinition,
     DescribeJob,
     DescribeJobDefinition,
     JobFile,
@@ -32,7 +38,7 @@ from jupyter_scheduler.models import (
     UpdateJobDefinition,
 )
 from jupyter_scheduler.orm import Job, JobDefinition, create_session
-from jupyter_scheduler.utils import create_output_filename
+from jupyter_scheduler.utils import create_output_directory, create_output_filename
 
 
 class BaseScheduler(LoggingConfigurable):
@@ -169,6 +175,10 @@ class BaseScheduler(LoggingConfigurable):
         """Returns list of all job definitions filtered by query"""
         raise NotImplementedError("must be implemented by subclass")
 
+    def create_job_from_definition(self, job_definition_id: str, model: CreateJobFromDefinition):
+        """Creates a new job based on a job definition"""
+        raise NotImplementedError("must be implemented by subclass")
+
     def get_staging_paths(self, model: Union[DescribeJob, DescribeJobDefinition]) -> Dict[str, str]:
         """Returns full staging paths for all job files
 
@@ -310,7 +320,7 @@ class BaseScheduler(LoggingConfigurable):
         where all the job files will be downloaded
         from the staging location.
         """
-        output_dir_name = create_output_filename(model.input_filename, model.create_time)
+        output_dir_name = create_output_directory(model.input_filename, model.job_id)
         return os.path.join(self.root_dir, self.output_directory, output_dir_name)
 
 
@@ -364,6 +374,14 @@ class Scheduler(BaseScheduler):
         if not model.job_definition_id and not self.file_exists(model.input_uri):
             raise InputUriError(model.input_uri)
 
+        input_path = os.path.join(self.root_dir, model.input_uri)
+        if not self.execution_manager_class.validate(self.execution_manager_class, input_path):
+            raise SchedulerError(
+                """There is no kernel associated with the notebook. Please open
+                    the notebook, select a kernel, and re-submit the job to execute.
+                    """
+            )
+
         with self.db_session() as session:
             if model.idempotency_token:
                 job = (
@@ -473,6 +491,12 @@ class Scheduler(BaseScheduler):
             if Status(job_record.status) == Status.IN_PROGRESS:
                 self.stop_job(job_id)
 
+            staging_paths = self.get_staging_paths(DescribeJob.from_orm(job_record))
+            if staging_paths:
+                path = os.path.dirname(next(iter(staging_paths.values())))
+                if os.path.exists(path):
+                    shutil.rmtree(path)
+
             session.query(Job).filter(Job.job_id == job_id).delete()
             session.commit()
 
@@ -601,6 +625,17 @@ class Scheduler(BaseScheduler):
 
         return list_response
 
+    def create_job_from_definition(self, job_definition_id: str, model: CreateJobFromDefinition):
+        job_id = None
+        definition = self.get_job_definition(job_definition_id)
+        if definition:
+            input_uri = self.get_staging_paths(definition)["input"]
+            attributes = definition.dict(exclude={"schedule", "timezone"}, exclude_none=True)
+            attributes = {**attributes, **model.dict(exclude_none=True), "input_uri": input_uri}
+            job_id = self.create_job(CreateJob(**attributes))
+
+        return job_id
+
     def get_staging_paths(self, model: Union[DescribeJob, DescribeJobDefinition]) -> Dict[str, str]:
         staging_paths = {}
         if not model:
