@@ -184,6 +184,26 @@ export class SchedulerService {
     return data as Scheduler.ICreateJobResponse;
   }
 
+  async createJobFromDefinition(
+    definition_id: string,
+    model: Scheduler.ICreateJobFromDefinition
+  ): Promise<Scheduler.ICreateJobResponse> {
+    let data;
+    try {
+      data = await requestAPI(
+        this.serverSettings,
+        `job_definitions/${definition_id}/jobs`,
+        {
+          method: 'POST',
+          body: JSON.stringify(model)
+        }
+      );
+    } catch (e: any) {
+      return Promise.reject(e);
+    }
+    return data as Scheduler.ICreateJobResponse;
+  }
+
   async setJobStatus(job_id: string, status: Scheduler.Status): Promise<void> {
     try {
       await requestAPI(this.serverSettings, `jobs/${job_id}`, {
@@ -254,6 +274,20 @@ export class SchedulerService {
     }
   }
 
+  async updateJobDefinition(
+    jobDefId: string,
+    model: Scheduler.IUpdateJobDefinition
+  ): Promise<void> {
+    try {
+      await requestAPI(this.serverSettings, `job_definitions/${jobDefId}`, {
+        method: 'PATCH',
+        body: JSON.stringify(model)
+      });
+    } catch (e) {
+      console.error(e);
+    }
+  }
+
   /**
    * The server settings used to make API requests.
    */
@@ -311,19 +345,20 @@ export namespace SchedulerService {
 }
 
 export namespace Scheduler {
-  export type RuntimeEnvironmentParameters = {
-    [key: string]: number | string | boolean;
-  };
-  export type Parameters = { [key: string]: number | string | boolean };
+  export type RuntimeEnvironmentParameters = Record<
+    string,
+    number | string | boolean
+  >;
+  export type Parameters = Record<string, string>;
 
   export interface ICreateJobDefinition {
+    name: string;
     input_uri: string;
     runtime_environment_name: string;
     runtime_environment_parameters?: RuntimeEnvironmentParameters;
     output_formats?: string[];
     parameters?: Parameters;
     tags?: string[];
-    name?: string;
     output_filename_template?: string;
     compute_type?: string;
     schedule?: string;
@@ -331,28 +366,20 @@ export namespace Scheduler {
   }
 
   export interface IUpdateJobDefinition {
-    runtime_environment_name?: string;
-    runtime_environment_parameters?: RuntimeEnvironmentParameters;
-    output_formats?: string[];
-    parameters?: Parameters;
-    tags?: string[];
     name?: string;
-    output_filename_template?: string;
-    compute_type?: string;
     schedule?: string;
     timezone?: string;
-    url?: string;
     active?: boolean;
   }
 
   export interface IDescribeJobDefinition {
+    name: string;
     input_filename: string;
     runtime_environment_name: string;
     runtime_environment_parameters?: RuntimeEnvironmentParameters;
     output_formats?: string[];
     parameters?: Parameters;
     tags?: string[];
-    name?: string;
     output_filename_template?: string;
     compute_type?: string;
     schedule?: string;
@@ -371,6 +398,7 @@ export namespace Scheduler {
   }
 
   export interface ICreateJob {
+    name: string;
     input_uri: string;
     runtime_environment_name: string;
     runtime_environment_parameters?: RuntimeEnvironmentParameters;
@@ -378,7 +406,6 @@ export namespace Scheduler {
     job_definition_id?: string;
     parameters?: Parameters;
     tags?: string[];
-    name?: string;
     email_notifications?: IEmailNotifications;
     timeout_seconds?: number;
     max_retries?: number;
@@ -389,6 +416,10 @@ export namespace Scheduler {
     compute_type?: string;
   }
 
+  export interface ICreateJobFromDefinition {
+    parameters?: Parameters;
+  }
+
   export type Status =
     | 'CREATED'
     | 'QUEUED'
@@ -405,6 +436,7 @@ export namespace Scheduler {
   }
 
   export interface IDescribeJob {
+    name: string;
     input_filename: string;
     runtime_environment_name: string;
     runtime_environment_parameters?: RuntimeEnvironmentParameters;
@@ -412,7 +444,6 @@ export namespace Scheduler {
     job_definition_id?: string;
     parameters?: Parameters;
     tags?: string[];
-    name?: string;
     email_notifications?: IEmailNotifications;
     timeout_seconds?: number;
     max_retries?: number;
