@@ -1,22 +1,24 @@
 import React, { useMemo } from 'react';
-import { IJobDefinitionModel, JobsView, ICreateJobModel } from '../../model';
+import {
+  IJobDefinitionModel,
+  JobsView,
+  ICreateJobModel,
+  emptyCreateJobModel
+} from '../../model';
 import { useTranslator } from '../../hooks';
-import { TextFieldStyled, timestampLocalize } from './job-detail';
+import { timestampLocalize } from './job-detail';
 import { SchedulerService } from '../../handler';
 import cronstrue from 'cronstrue';
 import { ListJobsTable } from '../list-jobs';
 import { Scheduler as SchedulerTokens } from '../../tokens';
 
-import {
-  Button,
-  Card,
-  CardContent,
-  FormLabel,
-  Stack,
-  TextFieldProps
-} from '@mui/material';
-import { ConfirmDeleteButton } from '../../components/confirm-delete-button';
+import { Button, Card, CardContent, FormLabel, Stack } from '@mui/material';
+import { ConfirmDialogDeleteButton } from '../../components/confirm-dialog-buttons';
 import { JupyterFrontEnd } from '@jupyterlab/application';
+import {
+  ILabeledValueProps,
+  LabeledValue
+} from '../../components/labeled-value';
 
 export interface IJobDefinitionProps {
   app: JupyterFrontEnd;
@@ -25,6 +27,7 @@ export interface IJobDefinitionProps {
   setJobsView: (view: JobsView) => void;
   showJobDetail: (jobId: string) => void;
   showCreateJob: (state: ICreateJobModel) => void;
+  editJobDefinition: (jobDefinition: IJobDefinitionModel) => void;
   advancedOptions: React.FunctionComponent<SchedulerTokens.IAdvancedOptionsProps>;
 }
 
@@ -48,6 +51,23 @@ export function JobDefinition(props: IJobDefinitionProps): JSX.Element {
     props.refresh();
   };
 
+  const runJobDefinition = () => {
+    const initialState: ICreateJobModel = {
+      ...emptyCreateJobModel(),
+      inputFile: props.model.inputFile,
+      outputPath: props.model.outputPrefix ?? '',
+      environment: props.model.environment,
+      computeType: props.model.computeType,
+      runtimeEnvironmentParameters: props.model.runtimeEnvironmentParameters,
+      parameters: props.model.parameters,
+      outputFormats: props.model.outputFormats,
+      jobDefinitionId: props.model.definitionId
+    };
+
+    props.showCreateJob(initialState);
+    props.setJobsView(JobsView.CreateFromJobDescriptionForm);
+  };
+
   let cronString;
   try {
     if (props.model.schedule !== undefined) {
@@ -59,6 +79,9 @@ export function JobDefinition(props: IJobDefinitionProps): JSX.Element {
 
   const DefinitionButtonBar = (
     <Stack direction="row" gap={2} justifyContent="flex-end" flexWrap={'wrap'}>
+      <Button variant="outlined" onClick={runJobDefinition}>
+        {trans.__('Run Job')}
+      </Button>
       {props.model.active ? (
         <Button variant="outlined" onClick={pauseJobDefinition}>
           {trans.__('Pause')}
@@ -68,17 +91,23 @@ export function JobDefinition(props: IJobDefinitionProps): JSX.Element {
           {trans.__('Resume')}
         </Button>
       )}
-      <ConfirmDeleteButton
+      <Button
+        variant="outlined"
+        onClick={() => props.editJobDefinition(props.model)}
+      >
+        {trans.__('Edit Job Definition')}
+      </Button>
+      <ConfirmDialogDeleteButton
         handleDelete={handleDeleteJobDefinition}
         title={trans.__('Delete Job Definition')}
-        text={trans.__(
+        dialogText={trans.__(
           'Are you sure that you want to delete this job definition?'
         )}
       />
     </Stack>
   );
 
-  const jobDefinitionFields: TextFieldProps[][] = [
+  const jobDefinitionFields: ILabeledValueProps[][] = [
     [{ value: props.model.name, label: trans.__('Name') }],
     [
       {
@@ -130,10 +159,10 @@ export function JobDefinition(props: IJobDefinitionProps): JSX.Element {
           {jobDefinitionFields.map(propsRow => (
             <Stack direction={'row'} gap={2} flexWrap={'wrap'}>
               {propsRow.map(textProp => (
-                <TextFieldStyled
+                <LabeledValue
                   {...textProp}
                   style={{
-                    flexGrow: 1
+                    flex: '1 1 49%'
                   }}
                 />
               ))}
@@ -177,6 +206,9 @@ export function JobDefinition(props: IJobDefinitionProps): JSX.Element {
             showJobDetail={props.showJobDetail}
             jobDefinitionId={props.model.definitionId}
             pageSize={5}
+            emptyRowMessage={trans.__(
+              'No notebook jobs associated with this job definition.'
+            )}
           />
         </Stack>
       </CardContent>
