@@ -1,7 +1,9 @@
+import { VDomModel } from '@jupyterlab/apputils';
+
 import { Signal } from '@lumino/signaling';
 import { PartialJSONObject } from '@lumino/coreutils';
+
 import { Scheduler } from './handler';
-import { VDomModel } from '@jupyterlab/apputils';
 
 /**
  * Top-level models
@@ -10,10 +12,12 @@ import { VDomModel } from '@jupyterlab/apputils';
 export enum JobsView {
   // assignment ensures any enum value is always truthy
   CreateForm = 1,
+  CreateFromJobDescriptionForm,
   ListJobs,
   ListJobDefinitions,
   JobDetail,
-  JobDefinitionDetail
+  JobDefinitionDetail,
+  EditJobDefinition
 }
 
 export type IJobParameter = {
@@ -26,7 +30,33 @@ export interface IOutputFormat {
   readonly label: string;
 }
 
-export interface ICreateJobModel extends PartialJSONObject {
+/**
+ * Extended by models which back UIs using the <ScheduleInputs /> component.
+ */
+export type ModelWithScheduleFields = {
+  // Intervals: 'minute' | 'hour' | 'day' | 'week' | 'weekday' | 'month' | 'custom'
+  scheduleInterval: string;
+  // String for schedule in cron format
+  schedule?: string;
+  // String for timezone in tz database format
+  timezone?: string;
+  // "Easy scheduling" inputs
+  // Minute for an input that only accepts minutes (of the hour)
+  scheduleMinuteInput?: string;
+  scheduleHourMinute?: number;
+  // Hour and minute for time inputs
+  scheduleTimeInput?: string;
+  scheduleMinute?: number;
+  scheduleHour?: number;
+  scheduleMonthDayInput?: string;
+  scheduleMonthDay?: number;
+  scheduleWeekDay?: string;
+  scheduleTime?: number;
+};
+
+export interface ICreateJobModel
+  extends ModelWithScheduleFields,
+    PartialJSONObject {
   /**
    * Key of the CreateJob component. When changed, this forces a re-mount.
    */
@@ -34,6 +64,8 @@ export interface ICreateJobModel extends PartialJSONObject {
   jobName: string;
   inputFile: string;
   environment: string;
+  // If creating a job from a job definition, the job definition ID to use.
+  jobDefinitionId?: string;
   // A "job" runs now; a "job definition" runs on a schedule
   createType: 'Job' | 'JobDefinition';
   // Errors from creation
@@ -45,23 +77,6 @@ export interface ICreateJobModel extends PartialJSONObject {
   computeType?: string;
   idempotencyToken?: string;
   tags?: string[];
-  // String for schedule in cron format
-  schedule?: string;
-  // String for timezone in tz database format
-  timezone?: string;
-  // "Easy scheduling" inputs
-  // Intervals: 'minute' | 'hour' | 'day' | 'week' | 'weekday' | 'month' | 'custom'
-  scheduleInterval: string;
-  // Minute for an input that only accepts minutes (of the hour)
-  scheduleMinuteInput?: string;
-  scheduleHourMinute?: number;
-  // Hour and minute for time inputs
-  scheduleTimeInput?: string;
-  scheduleMinute?: number;
-  scheduleHour?: number;
-  scheduleMonthDayInput?: string;
-  scheduleMonthDay?: number;
-  scheduleWeekDay?: string;
   // Is the create button disabled due to a submission in progress?
   createInProgress?: boolean;
 }
@@ -80,6 +95,21 @@ export function emptyCreateJobModel(): ICreateJobModel {
   };
 }
 
+export interface IUpdateJobDefinitionModel
+  extends ModelWithScheduleFields,
+    PartialJSONObject {
+  definitionId: string;
+  name?: string;
+}
+
+export function emptyUpdateJobDefinitionModel(): IUpdateJobDefinitionModel {
+  return {
+    definitionId: '',
+    schedule: '',
+    scheduleInterval: 'custom'
+  };
+}
+
 // eslint-disable-next-line @typescript-eslint/no-empty-interface
 export interface IListJobsModel extends PartialJSONObject {
   /* reserved */
@@ -104,6 +134,7 @@ export interface IJobsModel extends PartialJSONObject {
   createJobModel?: ICreateJobModel;
   listJobsModel?: IListJobsModel;
   jobDetailModel?: IDetailViewModel;
+  updateJobDefinitionModel?: IUpdateJobDefinitionModel;
 }
 
 export class JobsModel extends VDomModel {
@@ -111,6 +142,7 @@ export class JobsModel extends VDomModel {
   private _createJobModel: ICreateJobModel;
   private _listJobsModel: IListJobsModel;
   private _jobDetailModel: IDetailViewModel;
+  private _updateJobDefinitionModel: IUpdateJobDefinitionModel;
   /**
    * Callback that gets invoked whenever a model is updated. This should be used
    * to call `ReactWidget.renderDOM()` to synchronously update the VDOM rather
@@ -125,6 +157,7 @@ export class JobsModel extends VDomModel {
     this._createJobModel = emptyCreateJobModel();
     this._listJobsModel = emptyListJobsModel();
     this._jobDetailModel = emptyDetailViewModel();
+    this._updateJobDefinitionModel = emptyUpdateJobDefinitionModel();
     this._onModelUpdate = options.onModelUpdate;
     this._jobCount = 0;
   }
@@ -169,6 +202,16 @@ export class JobsModel extends VDomModel {
     this.stateChanged.emit(void 0);
   }
 
+  get updateJobDefinitionModel(): IUpdateJobDefinitionModel {
+    return this._updateJobDefinitionModel;
+  }
+
+  set updateJobDefinitionModel(model: IUpdateJobDefinitionModel) {
+    this._updateJobDefinitionModel = model;
+    this._onModelUpdate?.();
+    this.stateChanged.emit(void 0);
+  }
+
   get jobCount(): number {
     return this._jobCount;
   }
@@ -182,7 +225,8 @@ export class JobsModel extends VDomModel {
       jobsView: this.jobsView,
       createJobModel: this.createJobModel,
       listJobsModel: this.listJobsModel,
-      jobDetailModel: this.jobDetailModel
+      jobDetailModel: this.jobDetailModel,
+      updateJobDefinitionModel: this.updateJobDefinitionModel
     };
     return data;
   }
@@ -192,6 +236,8 @@ export class JobsModel extends VDomModel {
     this._createJobModel = data.createJobModel ?? emptyCreateJobModel();
     this._listJobsModel = data.listJobsModel ?? emptyListJobsModel();
     this._jobDetailModel = data.jobDetailModel ?? emptyDetailViewModel();
+    this._updateJobDefinitionModel =
+      data.updateJobDefinitionModel ?? emptyUpdateJobDefinitionModel();
 
     // emit state changed signal
     this._onModelUpdate?.();
@@ -233,6 +279,7 @@ export interface IJobDetailModel {
 }
 
 export interface IJobDefinitionModel {
+  name: string;
   inputFile: string;
   outputPath: string;
   environment: string;
@@ -249,7 +296,6 @@ export interface IJobDefinitionModel {
   // String for timezone in tz database format
   timezone?: string;
   definitionId: string;
-  name?: string;
   active?: boolean;
   createTime?: number;
   updateTime?: number;
@@ -288,7 +334,7 @@ export function convertDescribeJobtoJobDetail(
   return {
     ...emptyCreateJobModel(),
     jobId: describeJob.job_id,
-    jobName: describeJob.name ?? '',
+    jobName: describeJob.name,
     inputFile: describeJob.input_filename,
     job_files: convertJobFilesToJson(describeJob.job_files),
     environment: describeJob.runtime_environment_name,
@@ -317,7 +363,7 @@ export function convertDescribeDefinitiontoDefinition(
   );
 
   return {
-    name: describeDefinition.name ?? '',
+    name: describeDefinition.name,
     inputFile: describeDefinition.input_filename,
     definitionId: describeDefinition.job_definition_id,
     outputPath: describeDefinition.output_filename_template ?? '',
